##  Benefits
  * Embed SAP LeanIX content: Integrate any of your reports, diagrams, or fact sheets into Confluence. Examples include roadmap reports, free draw diagrams, and organization fact sheets.
  * Access live data: All changes made to reports, diagrams, and fact sheets in SAP LeanIX also apply to the content embedded in your Confluence pages. You can even navigate to SAP LeanIX from embedded items.
  * Configure data displayed: Use filters to customize the data set displayed in embedded items, or add saved searches to any page. You can resize reports and diagrams to ensure all information is visible on your Confluence page.
